Package: DOPE
Title: Drug Ontology Parsing Engine
Version: 2.1.0
Authors@R: c(
    person(given = "Raymond",
           family = "Balise",
           role = c("aut", "cre"),
           email = "balise@miami.edu",
           comment = c(ORCID = "0000-0002-9856-5901")),
    person(given = "Layla",
           family = "Bouzoubaa",
           role = c("aut"),
           email = "lab218@miami.edu",
           comment = c(ORCID = "0000-0002-6616-0950")),
    person(given = "Gabriel",
           family = "Odom",
           role = c("aut"),
           email = "gabriel.odom@fiu.edu",
           comment = c(ORCID = "0000-0003-1341-4555")),
    person(given = "Nathaniel",
           family = "Castor",
           role = c("aut"),
           email = "nxc741@miami.edu"))
Description: Provides information on drug names (brand, 
    generic and street) for drugs tracked by the DEA. There are functions that 
    will search synonyms and return the drug names and types. The vignettes 
    have extensive information on the work done to create the data for the package.
License: MIT + file LICENSE
URL: https://ctn-0094.github.io/DOPE/, https://github.com/CTN-0094/DOPE
BugReports: https://github.com/CTN-0094/DOPE/issues
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.1
Depends: R (>= 2.10)
Imports: dplyr, magrittr, stats, stringr, tibble, tidytext, utils
Suggests: purrr, knitr, rmarkdown, conflicted, readr, rvest, sqldf,
        tidyr, testthat, usethis, xml2
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2021-06-18 18:09:49 UTC; godom
Author: Raymond Balise [aut, cre] (<https://orcid.org/0000-0002-9856-5901>),
  Layla Bouzoubaa [aut] (<https://orcid.org/0000-0002-6616-0950>),
  Gabriel Odom [aut] (<https://orcid.org/0000-0003-1341-4555>),
  Nathaniel Castor [aut]
Maintainer: Raymond Balise <balise@miami.edu>
Repository: CRAN
Date/Publication: 2021-06-18 18:40:02 UTC
Built: R 4.6.0; ; 2026-04-29 15:46:24 UTC; unix
