# Generated by roxygen2: do not edit by hand

export(compress_lookup)
export(lookup)
export(lookup_syn)
export(parse)
importFrom(dplyr,anti_join)
importFrom(dplyr,case_when)
importFrom(dplyr,filter)
importFrom(dplyr,mutate)
importFrom(magrittr,"%>%")
importFrom(stats,na.omit)
importFrom(stringr,str_detect)
importFrom(stringr,str_replace_all)
importFrom(tibble,tibble)
importFrom(tidytext,unnest_tokens)
importFrom(utils,data)
