# Files from DEA

+ DIR-020-17DrugSlangCodeWords.pdf
+ c_cs_alpha.pdf  

# Files we created for vignettes
+ Drugs.jpg 

# Code files that should be vignettes

+ ontology.Rmd
+ controlled.Rmd
+ scrape_dea.R
+ scrape_slang.R
+ slang.Rmd

# Files that were manually tweaked:

+ slangUE.txt
+ Difficult_Edited.csv   
+ c_cs_alpha.xlsx

# Files we created while processing the data

+ Difficult.csv                    
          
    
